@@ -1,3 +1,22 @@
+#######################################################################
+# nuggets: An R framework for exploration of patterns in data
+# Copyright (C) 2025 Michal Burda
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <https://www.gnu.org/licenses/>.
+#######################################################################
+
+
 #' Convert columns of a data frame to Boolean or fuzzy sets
 #' (triangular, trapezoidal, or raised-cosine)
 #'
@@ -385,7 +404,8 @@ partition <- function(.data,
     args <- list(var = x,
                  n = span + (n - 1) * inc,
                  style = style,
-                 intervalClosure = if (right) "right" else "left")
+                 intervalClosure = if (right) "right" else "left",
+                 warnSmallN = FALSE)
     args <- c(args, style_params)
     ii <- do.call(classIntervals, args)
 
